from person_descriptor.descriptor import get_description

def start_app():
    while True:
        print("Aby zakonczyc aplikacje wpisz x")
        given_age = input("Podaj swoj wiek: ")

        if given_age == "x":
            print("Do widzenia")
            exit()

        age_description = get_description(int(given_age))
        print(f"Twoja grupa wiekowa to: {age_description}")


if __name__ == '__main__':
    start_app()



from setuptools import setup, find_packages

setup(
    name="age_descriptor",
    version="0.1",
    author="SDA",
    author_email="maila@mail.com",
    packages=find_packages(),
    python_requires=">=3.8",
    description="Our first super useful library",
    install_requires=[
        "pylint==2.11.1"
    ],
    entry_points="""
    [console_scripts]
    person_descriptor=person_descriptor.runner:start_app
    """
)


def get_description(age: int) -> str:
    if age < 0:
        return f"Podany wiek jest błędny: {age}"
    if age < 18:
        return f"Nastolatek"
    if age < 30:
        return f"Mlody"
    if age < 50:
        return f"dojrzaly"
    if age < 65:
        return f"wiekowy"
    return "Emeryt"